Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(306)

Unified Diff: Source/bindings/core/v8/WorkerScriptController.cpp

Issue 1115923002: workers: Rename WorkerThread to WorkerScript. Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: . Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/bindings/core/v8/WorkerScriptController.cpp
diff --git a/Source/bindings/core/v8/WorkerScriptController.cpp b/Source/bindings/core/v8/WorkerScriptController.cpp
index c1d852cc41976d26ae5bda63f5726cc090c91a3f..4ed8549b734c3a78b2dcbec423a1138e171753df 100644
--- a/Source/bindings/core/v8/WorkerScriptController.cpp
+++ b/Source/bindings/core/v8/WorkerScriptController.cpp
@@ -49,7 +49,7 @@
#include "core/workers/SharedWorkerGlobalScope.h"
#include "core/workers/WorkerGlobalScope.h"
#include "core/workers/WorkerObjectProxy.h"
-#include "core/workers/WorkerThread.h"
+#include "core/workers/WorkerScript.h"
#include "platform/heap/ThreadState.h"
#include "public/platform/Platform.h"
#include <v8.h>
@@ -120,9 +120,9 @@ WorkerScriptController::~WorkerScriptController()
m_world->dispose();
// The corresponding call to didStartRunLoop() is in WorkerThread::initialize().
// See http://webkit.org/b/83104#c14 for why this is here.
- m_workerGlobalScope.thread()->didStopRunLoop();
+ m_workerGlobalScope.script()->didStopRunLoop();
if (isContextInitialized())
m_scriptState->disposePerContextData();
@@ -166,7 +166,7 @@ bool WorkerScriptController::initializeContextIfNeeded()
v8::Isolate* WorkerScriptController::isolate() const
{
- return m_workerGlobalScope.thread()->isolate();
+ return m_workerGlobalScope.script()->isolate();
}
ScriptValue WorkerScriptController::evaluate(const String& script, const String& fileName, const TextPosition& scriptStartPosition, CachedMetadataHandler* cacheHandler, V8CacheOptions v8CacheOptions)
@@ -120,9 +120,9 @@ WorkerScriptController::~WorkerScriptController()
m_world->dispose();
- // The corresponding call to didStartRunLoop() is in WorkerThread::initialize().
+ // The corresponding call to didStartRunLoop() is in WorkerScript::initialize().
// See http://webkit.org/b/83104#c14 for why this is here.

Powered by Google App Engine
This is Rietveld 408576698